@@ -163,14 +163,14 @@ static GtkWidget   * __widget_key_categories_menu = NULL;
 static GtkWidget   * __widget_key_filter          = NULL;
 static GtkWidget   * __widget_key_filter_button   = NULL;
 static GtkWidget   * __widget_key_list_view       = NULL;
-static GtkTooltips * __widget_tooltips           = NULL;
+static GtkTooltips * __widget_tooltips            = NULL;
 
 static BoolConfigData __config_bool_common [] =
 {
     {
         SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD,
         SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD_DEFAULT,
-        N_("Start conversion on inputting comma or period."),
+        N_("_Start conversion on inputting comma or period."),
         NULL,
         N_("Start conversion on inputting comma or period."),
         NULL,
@@ -179,7 +179,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_COMMIT_PERIOD,
         SCIM_PRIME_CONFIG_COMMIT_PERIOD_DEFAULT,
-        N_("Commit comma and period immediately."),
+        N_("Commit comma and period _immediately."),
         NULL,
         N_("Commit comma and period immediatly on inputting these characters "
            "when no preedition string exists."),
@@ -189,7 +189,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_COMMIT_ON_UPPER,
         SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT,
-        N_("Commit on inputting upper letter."),
+        N_("Commit on inputting _upper letter."),
         NULL,
         N_("Commit previous preedit string when a upper letter is entered."),
         NULL,
@@ -198,7 +198,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION,
         SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT,
-        N_("Predict while typing letters."),
+        N_("_Predict while typing letters."),
         NULL,
         N_("Show candidates window to display predicted candidates "
            "while typing letters."),
@@ -208,7 +208,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION,
         SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION_DEFAULT,
-        N_("Use direct select keys also on prediction."),
+        N_("Use _direct select keys also on prediction."),
         NULL,
         N_("Use direct select keys not only for conversion state "
            "but also for prediction state."),
@@ -218,7 +218,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_INLINE_PREDICTION,
         SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT,
-        N_("Inline prediction."),
+        N_("_Inline prediction."),
         NULL,
         N_("Show first candidate of predictions instead of reading on preedit area. "
            "Reading is shown by external window."),
@@ -228,7 +228,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_AUTO_REGISTER,
         SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT,
-        N_("Change to inline word register mode automatically."),
+        N_("Change to the inline word _register mode automatically."),
         NULL,
         N_("Invoke the inline word register mode when the cursor in the "
            "candidates window is move to out of range."),
@@ -238,7 +238,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT,
         SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT,
-        N_("Close candidates window when a candidate is selected directly."),
+        N_("_Close candidates window when a candidate is selected directly."),
         NULL,
         N_("Close candidates window when a candidate is selected directly."),
         NULL,
@@ -247,7 +247,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_SHOW_ANNOTATION,
         SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT,
-        N_("Show annotation of the word on the candidates window"),
+        N_("Show _annotation of the word on the candidates window"),
         NULL,
         N_("Show annotation of the word on the candidates window."),
         NULL,
@@ -256,7 +256,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_SHOW_USAGE,
         SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT,
-        N_("Show usage of the word on the candidates window"),
+        N_("Show _usage of the word on the candidates window"),
         NULL,
         N_("Show usage of the word on the candidates window."),
         NULL,
@@ -265,7 +265,7 @@ static BoolConfigData __config_bool_common [] =
     {
         SCIM_PRIME_CONFIG_SHOW_COMMENT,
         SCIM_PRIME_CONFIG_SHOW_COMMENT_DEFAULT,
-        N_("Show comment of the word on the candidates window"),
+        N_("Show co_mment of the word on the candidates window"),
         NULL,
         N_("Show comment of the word on the candidates window."),
         NULL,
@@ -279,12 +279,21 @@ static StringConfigData __config_string_common [] =
     {
         SCIM_PRIME_CONFIG_COMMAND,
         SCIM_PRIME_CONFIG_COMMAND_DEFAULT,
-        N_("PRIME command:"),
+        N_("PRIME _command:"),
         NULL,
         N_("The PRIME command to use as conversion engine."),
         NULL,
         false,
     },
+    {
+        SCIM_PRIME_CONFIG_PREDICT_WIN_POS,
+        SCIM_PRIME_CONFIG_PREDICT_WIN_POS_DEFAULT,
+        N_("Prediction _window position:"),
+        NULL,
+        N_("The prediction window position to show."),
+        NULL,
+        false,
+    },
 };
 static unsigned int __config_string_common_num = sizeof (__config_string_common) / sizeof (StringConfigData);
 
@@ -764,6 +773,13 @@ static unsigned int __key_conf_pages_num = sizeof (__key_conf_pages) / sizeof (K
 const int INDEX_SEARCH_BY_KEY = __key_conf_pages_num;
 const int INDEX_ALL           = __key_conf_pages_num + 1;
 
+static ComboConfigCandidate predict_win_pos[] =
+{
+    {N_("Head of preedition area"), "head"},
+    {N_("Tail of preedition area"), "tail"},
+    {NULL, NULL},
+};
+
 
 static void on_default_editable_changed       (GtkEditable     *editable,
                                                gpointer         user_data);
@@ -772,9 +788,9 @@ static void on_default_toggle_button_toggled  (GtkToggleButton *togglebutton,
 #if 0
 static void on_default_key_selection_clicked  (GtkButton       *button,
                                                gpointer         user_data);
+#endif
 static void on_default_combo_changed          (GtkEditable     *editable,
                                                gpointer         user_data);
-#endif
 static void     on_key_filter_selection_clicked   (GtkButton       *button,
                                                    gpointer         user_data);
 static void     on_key_category_menu_changed      (GtkOptionMenu   *omenu,
@@ -854,7 +870,6 @@ match_key_event (const KeyEventList &list, const KeyEvent &key)
     return false;
 }
 
-#if 0
 static GtkWidget *
 create_combo (const char *config_key, gpointer candidates_p,
               GtkWidget *table, gint idx)
@@ -898,7 +913,6 @@ create_combo (const char *config_key, gpointer candidates_p,
 
     return entry->widget;
 }
-#endif
 
 #define APPEND_ENTRY(data, i)                                                  \
 {                                                                              \
@@ -1050,14 +1064,17 @@ create_prediction_page ()
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
 
-    table = gtk_table_new (2, 2, FALSE);
-    gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 4);
-    gtk_widget_show (table);
-
     /* predict on preedition */
     widget = create_check_button (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 4);
 
+    /* prediction window position */
+    table = gtk_table_new (2, 2, FALSE);
+    gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 4);
+    gtk_widget_show (table);
+    widget = create_combo (SCIM_PRIME_CONFIG_PREDICT_WIN_POS,
+                           predict_win_pos, table, 0);
+
     /* use direct select keys on prediction */
     widget = create_check_button (SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 4);
@@ -1145,11 +1162,17 @@ create_keyboard_page (void)
     gtk_widget_show(hbox);
 
     // category menu
+    GtkWidget *label = gtk_label_new_with_mnemonic (_("_Group:"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
+    gtk_widget_show (label);
+
     GtkWidget *omenu = gtk_option_menu_new ();
     __widget_key_categories_menu = omenu;
     gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 2);
     gtk_widget_show (omenu);
 
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), omenu);
+
     GtkWidget *menu = gtk_menu_new ();
 
     GtkWidget *menuitem;
@@ -1252,7 +1275,7 @@ create_setup_window ()
 
         // Create the 1st page.
         GtkWidget *page = create_options_page ();
-        GtkWidget *label = gtk_label_new (_("Options"));
+        GtkWidget *label = gtk_label_new (_("Common"));
         gtk_widget_show (label);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
@@ -1497,7 +1520,6 @@ on_default_key_selection_clicked (GtkButton *button,
 }
 #endif
 
-#if 0
 static void
 on_default_combo_changed (GtkEditable *editable,
                           gpointer user_data)
@@ -1521,7 +1543,6 @@ on_default_combo_changed (GtkEditable *editable,
         }
     }
 }
-#endif
 
 static void
 on_key_category_menu_changed (GtkOptionMenu *omenu, gpointer user_data)
