@@ -91,7 +91,7 @@
 #define SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT             false
 
 #define SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT       true
-#define SCIM_PRIME_CONFIG_PREDICT_WIN_POS_DEFAULT             "head"
+#define SCIM_PRIME_CONFIG_PREDICT_WIN_POS_DEFAULT             "tail"
 #define SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION_DEFAULT true
 #define SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT           false
 
